@@ -26,6 +26,17 @@
  *
  */
 
+/**
+ * SECTION:totem-cell-renderer-video
+ * @short_description: a #GtkCellRenderer widget for listing videos
+ * @stability: Unstable
+ * @include: totem-cell-renderer-video.h
+ * @see_also: #TotemVideoList
+ *
+ * #TotemCellRendererVideo is a #GtkCellRenderer for rendering video thumbnails, typically in a #TotemVideoList.
+ * It supports drawing a video thumbnail, and the video's title underneath.
+ **/
+
 #include "config.h"
 
 #include <glib.h>
@@ -65,7 +76,7 @@ G_DEFINE_TYPE (TotemCellRendererVideo, totem_cell_renderer_video, GTK_TYPE_CELL_
  * totem_cell_renderer_video_new:
  * @use_placeholder: if %TRUE, use a placeholder thumbnail
  *
- * Creates a new #TotemCellRendererVideo with its :use-placeholder
+ * Creates a new #TotemCellRendererVideo with its #TotemCellRendererVideo:use-placeholder
  * property set to @use_placeholder. If @use_placeholder is %TRUE,
  * the renderer will display a generic placeholder thumbnail if a
  * proper one is not available.
@@ -94,17 +105,41 @@ totem_cell_renderer_video_class_init (TotemCellRendererVideoClass *klass)
 	renderer_class->get_size = totem_cell_renderer_video_get_size;
 	renderer_class->render = totem_cell_renderer_video_render;
 
+	/**
+	 * TotemCellRendererVideo:thumbnail:
+	 *
+	 * A #GdkPixbuf of a thumbnail of the video to display. When rendered, it will scale to the width of the parent #GtkTreeView,
+	 * so can be as large as reasonable.
+	 **/
 	g_object_class_install_property (object_class, PROP_THUMBNAIL,
 				g_param_spec_object ("thumbnail", NULL, NULL,
 					GDK_TYPE_PIXBUF, G_PARAM_READWRITE));
+
+	/**
+	 * TotemCellRendererVideo:title:
+	 *
+	 * The title of the video, as it should be displayed.
+	 **/
 	g_object_class_install_property (object_class, PROP_TITLE,
 				g_param_spec_string ("title", NULL, NULL,
 					_("Unknown video"), G_PARAM_READWRITE));
+
+	/**
+	 * TotemCellRendererVideo:alignment:
+	 *
+	 * A #PangoAlignment giving the text alignment for the video title.
+	 **/
 	g_object_class_install_property (object_class, PROP_ALIGNMENT,
 				g_param_spec_enum ("alignment", NULL, NULL,
 					PANGO_TYPE_ALIGNMENT,
 					PANGO_ALIGN_CENTER,
 					G_PARAM_READWRITE));
+
+	/**
+	 * TotemCellRendererVideo:use-placeholder:
+	 *
+	 * If %TRUE, a placeholder image should be used for the video thumbnail if a #TotemCellRendererVideo:thumbnail isn't provided.
+	 **/
 	g_object_class_install_property (object_class, PROP_USE_PLACEHOLDER,
 				g_param_spec_boolean ("use-placeholder", NULL, NULL,
 					FALSE, G_PARAM_READWRITE));
@@ -156,7 +191,7 @@ totem_cell_renderer_video_set_property (GObject *object, guint property_id, cons
 			break;
 		case PROP_TITLE:
 			g_free (priv->title);
-			priv->title = g_strdup (g_value_get_string (value));
+			priv->title = g_value_dup_string (value);
 			break;
 		case PROP_ALIGNMENT:
 			priv->alignment = g_value_get_enum (value);
